summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/winpopup/wpcontact.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/winpopup/wpcontact.h')
-rw-r--r--kopete/protocols/winpopup/wpcontact.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kopete/protocols/winpopup/wpcontact.h b/kopete/protocols/winpopup/wpcontact.h
index 93d18c53..c7bc336f 100644
--- a/kopete/protocols/winpopup/wpcontact.h
+++ b/kopete/protocols/winpopup/wpcontact.h
@@ -21,7 +21,7 @@
// KDE Includes
#include <kaction.h>
-// Qt Includes
+// TQt Includes
//#include <tqvaluestack.h>
#include <tqdatetime.h>
#include <tqptrlist.h>
@@ -49,6 +49,7 @@ namespace Kopete { class MetaContact; }
class WPContact: public Kopete::Contact
{
Q_OBJECT
+ TQ_OBJECT
public:
WPContact(Kopete::Account *account, const TQString &userId, const TQString &fullName, Kopete::MetaContact *metaContact);
@@ -61,7 +62,7 @@ public:
public slots:
virtual void slotUserInfo();
- void slotCheckStatus(); // the call back for the checkStatus timer
+ void slotChecktqStatus(); // the call back for the checktqStatus timer
void slotNewMessage(const TQString &Body, const TQDateTime &Arrival);
private slots:
@@ -72,7 +73,7 @@ private slots:
private:
bool myWasConnected; // true if protocol connected at last check
- TQTimer checkStatus; // checks the status of this contact every second or so
+ TQTimer checktqStatus; // checks the status of this contact every second or so
// KActionCollection *myActionCollection;
// holds all the protocol specific actions (not many!)
Kopete::ChatSession *m_manager;
@@ -83,4 +84,4 @@ private:
#endif
// vim: set noet ts=4 sts=4 sw=4:
-// kate: tab-width 4; indent-width 4; replace-trailing-space-save on;
+// kate: tab-width 4; indent-width 4; tqreplace-trailing-space-save on;